@@ -1,3 +1,5 @@
+/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
+
 #ifndef _GVM_H
 #define _GVM_H
 
@@ -10,6 +12,8 @@ struct gvm_configuration {
 	gboolean autobrowse;
 	gboolean autorun;
 	char *autorun_path;
+	gboolean autoopen;
+	char *autoopen_path;
 	
 	gboolean autoburn;
 	char *autoburn_audio_cd_command;
@@ -53,11 +57,9 @@ struct gvm_configuration {
 	
 	gboolean autopocketpc;
 	char *autopocketpc_command;
-	
-	char *eject_command;
-	
-	char *mount_command;
-	char *unmount_command;
+        
+        double percent_threshold;
+        double percent_used;
 };
 
 /* where our settings are rooted in the gconf tree */
